/****************************************************************************
** Meta object code from reading C++ file 'dvbchanneldialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/dvb/dvbchanneldialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dvbchanneldialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DvbChannelTableModel_t {
    QByteArrayData data[13];
    char stringdata0[164];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbChannelTableModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbChannelTableModel_t qt_meta_stringdata_DvbChannelTableModel = {
    {
QT_MOC_LITERAL(0, 0, 20), // "DvbChannelTableModel"
QT_MOC_LITERAL(1, 21, 23), // "checkChannelDragAndDrop"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 5), // "bool*"
QT_MOC_LITERAL(4, 52, 2), // "ok"
QT_MOC_LITERAL(5, 55, 9), // "setFilter"
QT_MOC_LITERAL(6, 65, 6), // "filter"
QT_MOC_LITERAL(7, 72, 12), // "channelAdded"
QT_MOC_LITERAL(8, 85, 16), // "DvbSharedChannel"
QT_MOC_LITERAL(9, 102, 7), // "channel"
QT_MOC_LITERAL(10, 110, 23), // "channelAboutToBeUpdated"
QT_MOC_LITERAL(11, 134, 14), // "channelUpdated"
QT_MOC_LITERAL(12, 149, 14) // "channelRemoved"

    },
    "DvbChannelTableModel\0checkChannelDragAndDrop\0"
    "\0bool*\0ok\0setFilter\0filter\0channelAdded\0"
    "DvbSharedChannel\0channel\0"
    "channelAboutToBeUpdated\0channelUpdated\0"
    "channelRemoved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbChannelTableModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   47,    2, 0x0a /* Public */,
       7,    1,   50,    2, 0x08 /* Private */,
      10,    1,   53,    2, 0x08 /* Private */,
      11,    1,   56,    2, 0x08 /* Private */,
      12,    1,   59,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void, 0x80000000 | 8,    9,

       0        // eod
};

void DvbChannelTableModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbChannelTableModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->checkChannelDragAndDrop((*reinterpret_cast< bool*(*)>(_a[1]))); break;
        case 1: _t->setFilter((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->channelAdded((*reinterpret_cast< const DvbSharedChannel(*)>(_a[1]))); break;
        case 3: _t->channelAboutToBeUpdated((*reinterpret_cast< const DvbSharedChannel(*)>(_a[1]))); break;
        case 4: _t->channelUpdated((*reinterpret_cast< const DvbSharedChannel(*)>(_a[1]))); break;
        case 5: _t->channelRemoved((*reinterpret_cast< const DvbSharedChannel(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DvbChannelTableModel::*)(bool * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbChannelTableModel::checkChannelDragAndDrop)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbChannelTableModel::staticMetaObject = { {
    QMetaObject::SuperData::link<TableModel<DvbChannelTableModelHelper>::staticMetaObject>(),
    qt_meta_stringdata_DvbChannelTableModel.data,
    qt_meta_data_DvbChannelTableModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbChannelTableModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbChannelTableModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbChannelTableModel.stringdata0))
        return static_cast<void*>(this);
    return TableModel<DvbChannelTableModelHelper>::qt_metacast(_clname);
}

int DvbChannelTableModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TableModel<DvbChannelTableModelHelper>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DvbChannelTableModel::checkChannelDragAndDrop(bool * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_DvbChannelView_t {
    QByteArrayData data[12];
    char stringdata0[156];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbChannelView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbChannelView_t qt_meta_stringdata_DvbChannelView = {
    {
QT_MOC_LITERAL(0, 0, 14), // "DvbChannelView"
QT_MOC_LITERAL(1, 15, 18), // "channelPidsUpdated"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 16), // "DvbSharedChannel"
QT_MOC_LITERAL(4, 52, 7), // "channel"
QT_MOC_LITERAL(5, 60, 23), // "checkChannelDragAndDrop"
QT_MOC_LITERAL(6, 84, 5), // "bool*"
QT_MOC_LITERAL(7, 90, 2), // "ok"
QT_MOC_LITERAL(8, 93, 11), // "editChannel"
QT_MOC_LITERAL(9, 105, 13), // "removeChannel"
QT_MOC_LITERAL(10, 119, 17), // "removeAllChannels"
QT_MOC_LITERAL(11, 137, 18) // "channelPidsChanged"

    },
    "DvbChannelView\0channelPidsUpdated\0\0"
    "DvbSharedChannel\0channel\0"
    "checkChannelDragAndDrop\0bool*\0ok\0"
    "editChannel\0removeChannel\0removeAllChannels\0"
    "channelPidsChanged"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbChannelView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   47,    2, 0x0a /* Public */,
       8,    0,   50,    2, 0x0a /* Public */,
       9,    0,   51,    2, 0x0a /* Public */,
      10,    0,   52,    2, 0x0a /* Public */,
      11,    1,   53,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void DvbChannelView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbChannelView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->channelPidsUpdated((*reinterpret_cast< const DvbSharedChannel(*)>(_a[1]))); break;
        case 1: _t->checkChannelDragAndDrop((*reinterpret_cast< bool*(*)>(_a[1]))); break;
        case 2: _t->editChannel(); break;
        case 3: _t->removeChannel(); break;
        case 4: _t->removeAllChannels(); break;
        case 5: _t->channelPidsChanged((*reinterpret_cast< const DvbSharedChannel(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DvbChannelView::*)(const DvbSharedChannel & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbChannelView::channelPidsUpdated)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbChannelView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_meta_stringdata_DvbChannelView.data,
    qt_meta_data_DvbChannelView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbChannelView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbChannelView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbChannelView.stringdata0))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int DvbChannelView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DvbChannelView::channelPidsUpdated(const DvbSharedChannel & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
