/****************************************************************************
** Meta object code from reading C++ file 'dvbtab.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/dvb/dvbtab.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dvbtab.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DvbTab_t {
    QByteArrayData data[28];
    char stringdata0[350];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbTab_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbTab_t qt_meta_stringdata_DvbTab = {
    {
QT_MOC_LITERAL(0, 0, 6), // "DvbTab"
QT_MOC_LITERAL(1, 7, 13), // "osdKeyPressed"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 3), // "key"
QT_MOC_LITERAL(4, 26, 19), // "mayCloseApplication"
QT_MOC_LITERAL(5, 46, 5), // "bool*"
QT_MOC_LITERAL(6, 52, 2), // "ok"
QT_MOC_LITERAL(7, 55, 8), // "QWidget*"
QT_MOC_LITERAL(8, 64, 6), // "parent"
QT_MOC_LITERAL(9, 71, 17), // "showChannelDialog"
QT_MOC_LITERAL(10, 89, 15), // "toggleEpgDialog"
QT_MOC_LITERAL(11, 105, 19), // "showRecordingDialog"
QT_MOC_LITERAL(12, 125, 13), // "instantRecord"
QT_MOC_LITERAL(13, 139, 7), // "checked"
QT_MOC_LITERAL(14, 147, 16), // "recordingRemoved"
QT_MOC_LITERAL(15, 164, 18), // "DvbSharedRecording"
QT_MOC_LITERAL(16, 183, 9), // "recording"
QT_MOC_LITERAL(17, 193, 12), // "configureDvb"
QT_MOC_LITERAL(18, 206, 14), // "tuneOsdChannel"
QT_MOC_LITERAL(19, 221, 11), // "playChannel"
QT_MOC_LITERAL(20, 233, 11), // "QModelIndex"
QT_MOC_LITERAL(21, 245, 5), // "index"
QT_MOC_LITERAL(22, 251, 15), // "previousChannel"
QT_MOC_LITERAL(23, 267, 11), // "nextChannel"
QT_MOC_LITERAL(24, 279, 19), // "cleanTimeShiftFiles"
QT_MOC_LITERAL(25, 299, 18), // "channelPidsUpdated"
QT_MOC_LITERAL(26, 318, 16), // "DvbSharedChannel"
QT_MOC_LITERAL(27, 335, 14) // "updatedChannel"

    },
    "DvbTab\0osdKeyPressed\0\0key\0mayCloseApplication\0"
    "bool*\0ok\0QWidget*\0parent\0showChannelDialog\0"
    "toggleEpgDialog\0showRecordingDialog\0"
    "instantRecord\0checked\0recordingRemoved\0"
    "DvbSharedRecording\0recording\0configureDvb\0"
    "tuneOsdChannel\0playChannel\0QModelIndex\0"
    "index\0previousChannel\0nextChannel\0"
    "cleanTimeShiftFiles\0channelPidsUpdated\0"
    "DvbSharedChannel\0updatedChannel"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbTab[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x0a /* Public */,
       4,    2,   87,    2, 0x0a /* Public */,
       9,    0,   92,    2, 0x08 /* Private */,
      10,    0,   93,    2, 0x08 /* Private */,
      11,    0,   94,    2, 0x08 /* Private */,
      12,    1,   95,    2, 0x08 /* Private */,
      14,    1,   98,    2, 0x08 /* Private */,
      17,    0,  101,    2, 0x08 /* Private */,
      18,    0,  102,    2, 0x08 /* Private */,
      19,    1,  103,    2, 0x08 /* Private */,
      22,    0,  106,    2, 0x08 /* Private */,
      23,    0,  107,    2, 0x08 /* Private */,
      24,    0,  108,    2, 0x08 /* Private */,
      25,    1,  109,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 7,    6,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 20,   21,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 26,   27,

       0        // eod
};

void DvbTab::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbTab *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->osdKeyPressed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->mayCloseApplication((*reinterpret_cast< bool*(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 2: _t->showChannelDialog(); break;
        case 3: _t->toggleEpgDialog(); break;
        case 4: _t->showRecordingDialog(); break;
        case 5: _t->instantRecord((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 6: _t->recordingRemoved((*reinterpret_cast< const DvbSharedRecording(*)>(_a[1]))); break;
        case 7: _t->configureDvb(); break;
        case 8: _t->tuneOsdChannel(); break;
        case 9: _t->playChannel((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 10: _t->previousChannel(); break;
        case 11: _t->nextChannel(); break;
        case 12: _t->cleanTimeShiftFiles(); break;
        case 13: _t->channelPidsUpdated((*reinterpret_cast< const DvbSharedChannel(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbTab::staticMetaObject = { {
    QMetaObject::SuperData::link<TabBase::staticMetaObject>(),
    qt_meta_stringdata_DvbTab.data,
    qt_meta_data_DvbTab,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbTab::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbTab::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbTab.stringdata0))
        return static_cast<void*>(this);
    return TabBase::qt_metacast(_clname);
}

int DvbTab::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TabBase::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
