/****************************************************************************
** Meta object code from reading C++ file 'dvbliveview_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/dvb/dvbliveview_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dvbliveview_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DvbLiveViewInternal_t {
    QByteArrayData data[14];
    char stringdata0[220];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbLiveViewInternal_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbLiveViewInternal_t qt_meta_stringdata_DvbLiveViewInternal = {
    {
QT_MOC_LITERAL(0, 0, 19), // "DvbLiveViewInternal"
QT_MOC_LITERAL(1, 20, 25), // "currentAudioStreamChanged"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 18), // "currentAudioStream"
QT_MOC_LITERAL(4, 66, 22), // "currentSubtitleChanged"
QT_MOC_LITERAL(5, 89, 15), // "currentSubtitle"
QT_MOC_LITERAL(6, 105, 6), // "replay"
QT_MOC_LITERAL(7, 112, 16), // "playbackFinished"
QT_MOC_LITERAL(8, 129, 21), // "playbackStatusChanged"
QT_MOC_LITERAL(9, 151, 27), // "MediaWidget::PlaybackStatus"
QT_MOC_LITERAL(10, 179, 14), // "playbackStatus"
QT_MOC_LITERAL(11, 194, 8), // "previous"
QT_MOC_LITERAL(12, 203, 4), // "next"
QT_MOC_LITERAL(13, 208, 11) // "writeToPipe"

    },
    "DvbLiveViewInternal\0currentAudioStreamChanged\0"
    "\0currentAudioStream\0currentSubtitleChanged\0"
    "currentSubtitle\0replay\0playbackFinished\0"
    "playbackStatusChanged\0MediaWidget::PlaybackStatus\0"
    "playbackStatus\0previous\0next\0writeToPipe"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbLiveViewInternal[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       7,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    1,   57,    2, 0x06 /* Public */,
       6,    0,   60,    2, 0x06 /* Public */,
       7,    0,   61,    2, 0x06 /* Public */,
       8,    1,   62,    2, 0x06 /* Public */,
      11,    0,   65,    2, 0x06 /* Public */,
      12,    0,   66,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    0,   67,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void DvbLiveViewInternal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbLiveViewInternal *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->currentAudioStreamChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->currentSubtitleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->replay(); break;
        case 3: _t->playbackFinished(); break;
        case 4: _t->playbackStatusChanged((*reinterpret_cast< MediaWidget::PlaybackStatus(*)>(_a[1]))); break;
        case 5: _t->previous(); break;
        case 6: _t->next(); break;
        case 7: _t->writeToPipe(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DvbLiveViewInternal::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveViewInternal::currentAudioStreamChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DvbLiveViewInternal::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveViewInternal::currentSubtitleChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DvbLiveViewInternal::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveViewInternal::replay)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DvbLiveViewInternal::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveViewInternal::playbackFinished)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DvbLiveViewInternal::*)(MediaWidget::PlaybackStatus );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveViewInternal::playbackStatusChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DvbLiveViewInternal::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveViewInternal::previous)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DvbLiveViewInternal::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveViewInternal::next)) {
                *result = 6;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbLiveViewInternal::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DvbLiveViewInternal.data,
    qt_meta_data_DvbLiveViewInternal,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbLiveViewInternal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbLiveViewInternal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbLiveViewInternal.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DvbPidFilter"))
        return static_cast< DvbPidFilter*>(this);
    if (!strcmp(_clname, "MediaSource"))
        return static_cast< MediaSource*>(this);
    return QObject::qt_metacast(_clname);
}

int DvbLiveViewInternal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void DvbLiveViewInternal::currentAudioStreamChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DvbLiveViewInternal::currentSubtitleChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DvbLiveViewInternal::replay()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DvbLiveViewInternal::playbackFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DvbLiveViewInternal::playbackStatusChanged(MediaWidget::PlaybackStatus _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void DvbLiveViewInternal::previous()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void DvbLiveViewInternal::next()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
