/****************************************************************************
** Meta object code from reading C++ file 'dbusobjects.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/dbusobjects.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusobjects.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MprisRootObject_t {
    QByteArrayData data[8];
    char stringdata0[107];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MprisRootObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MprisRootObject_t qt_meta_stringdata_MprisRootObject = {
    {
QT_MOC_LITERAL(0, 0, 15), // "MprisRootObject"
QT_MOC_LITERAL(1, 16, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 32, 27), // "org.freedesktop.MediaPlayer"
QT_MOC_LITERAL(3, 60, 8), // "Identity"
QT_MOC_LITERAL(4, 69, 0), // ""
QT_MOC_LITERAL(5, 70, 4), // "Quit"
QT_MOC_LITERAL(6, 75, 12), // "MprisVersion"
QT_MOC_LITERAL(7, 88, 18) // "MprisVersionStruct"

    },
    "MprisRootObject\0D-Bus Interface\0"
    "org.freedesktop.MediaPlayer\0Identity\0"
    "\0Quit\0MprisVersion\0MprisVersionStruct"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MprisRootObject[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       3,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    0,   31,    4, 0x0a /* Public */,
       5,    0,   32,    4, 0x0a /* Public */,
       6,    0,   33,    4, 0x0a /* Public */,

 // slots: parameters
    QMetaType::QString,
    QMetaType::Void,
    0x80000000 | 7,

       0        // eod
};

void MprisRootObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MprisRootObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { QString _r = _t->Identity();
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->Quit(); break;
        case 2: { MprisVersionStruct _r = _t->MprisVersion();
            if (_a[0]) *reinterpret_cast< MprisVersionStruct*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MprisRootObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_MprisRootObject.data,
    qt_meta_data_MprisRootObject,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MprisRootObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisRootObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MprisRootObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MprisRootObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
struct qt_meta_stringdata_MprisPlayerObject_t {
    QByteArrayData data[35];
    char stringdata0[403];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MprisPlayerObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MprisPlayerObject_t qt_meta_stringdata_MprisPlayerObject = {
    {
QT_MOC_LITERAL(0, 0, 17), // "MprisPlayerObject"
QT_MOC_LITERAL(1, 18, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 34, 27), // "org.freedesktop.MediaPlayer"
QT_MOC_LITERAL(3, 62, 11), // "TrackChange"
QT_MOC_LITERAL(4, 74, 0), // ""
QT_MOC_LITERAL(5, 75, 8), // "metadata"
QT_MOC_LITERAL(6, 84, 12), // "StatusChange"
QT_MOC_LITERAL(7, 97, 17), // "MprisStatusStruct"
QT_MOC_LITERAL(8, 115, 6), // "status"
QT_MOC_LITERAL(9, 122, 10), // "CapsChange"
QT_MOC_LITERAL(10, 133, 12), // "capabilities"
QT_MOC_LITERAL(11, 146, 4), // "Next"
QT_MOC_LITERAL(12, 151, 4), // "Prev"
QT_MOC_LITERAL(13, 156, 5), // "Pause"
QT_MOC_LITERAL(14, 162, 4), // "Stop"
QT_MOC_LITERAL(15, 167, 4), // "Play"
QT_MOC_LITERAL(16, 172, 6), // "Repeat"
QT_MOC_LITERAL(17, 179, 6), // "repeat"
QT_MOC_LITERAL(18, 186, 9), // "GetStatus"
QT_MOC_LITERAL(19, 196, 11), // "GetMetadata"
QT_MOC_LITERAL(20, 208, 7), // "GetCaps"
QT_MOC_LITERAL(21, 216, 9), // "VolumeSet"
QT_MOC_LITERAL(22, 226, 6), // "volume"
QT_MOC_LITERAL(23, 233, 9), // "VolumeGet"
QT_MOC_LITERAL(24, 243, 11), // "PositionSet"
QT_MOC_LITERAL(25, 255, 8), // "position"
QT_MOC_LITERAL(26, 264, 11), // "PositionGet"
QT_MOC_LITERAL(27, 276, 14), // "IncreaseVolume"
QT_MOC_LITERAL(28, 291, 14), // "DecreaseVolume"
QT_MOC_LITERAL(29, 306, 11), // "ToggleMuted"
QT_MOC_LITERAL(30, 318, 16), // "ToggleFullScreen"
QT_MOC_LITERAL(31, 335, 17), // "ShortSkipBackward"
QT_MOC_LITERAL(32, 353, 16), // "ShortSkipForward"
QT_MOC_LITERAL(33, 370, 16), // "LongSkipBackward"
QT_MOC_LITERAL(34, 387, 15) // "LongSkipForward"

    },
    "MprisPlayerObject\0D-Bus Interface\0"
    "org.freedesktop.MediaPlayer\0TrackChange\0"
    "\0metadata\0StatusChange\0MprisStatusStruct\0"
    "status\0CapsChange\0capabilities\0Next\0"
    "Prev\0Pause\0Stop\0Play\0Repeat\0repeat\0"
    "GetStatus\0GetMetadata\0GetCaps\0VolumeSet\0"
    "volume\0VolumeGet\0PositionSet\0position\0"
    "PositionGet\0IncreaseVolume\0DecreaseVolume\0"
    "ToggleMuted\0ToggleFullScreen\0"
    "ShortSkipBackward\0ShortSkipForward\0"
    "LongSkipBackward\0LongSkipForward"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MprisPlayerObject[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
      24,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,  136,    4, 0x06 /* Public */,
       6,    1,  139,    4, 0x06 /* Public */,
       9,    1,  142,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      11,    0,  145,    4, 0x0a /* Public */,
      12,    0,  146,    4, 0x0a /* Public */,
      13,    0,  147,    4, 0x0a /* Public */,
      14,    0,  148,    4, 0x0a /* Public */,
      15,    0,  149,    4, 0x0a /* Public */,
      16,    1,  150,    4, 0x0a /* Public */,
      18,    0,  153,    4, 0x0a /* Public */,
      19,    0,  154,    4, 0x0a /* Public */,
      20,    0,  155,    4, 0x0a /* Public */,
      21,    1,  156,    4, 0x0a /* Public */,
      23,    0,  159,    4, 0x0a /* Public */,
      24,    1,  160,    4, 0x0a /* Public */,
      26,    0,  163,    4, 0x0a /* Public */,
      27,    0,  164,    4, 0x0a /* Public */,
      28,    0,  165,    4, 0x0a /* Public */,
      29,    0,  166,    4, 0x0a /* Public */,
      30,    0,  167,    4, 0x0a /* Public */,
      31,    0,  168,    4, 0x0a /* Public */,
      32,    0,  169,    4, 0x0a /* Public */,
      33,    0,  170,    4, 0x0a /* Public */,
      34,    0,  171,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QVariantMap,    5,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, QMetaType::Int,   10,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   17,
    0x80000000 | 7,
    QMetaType::QVariantMap,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,   22,
    QMetaType::Int,
    QMetaType::Void, QMetaType::Int,   25,
    QMetaType::Int,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void MprisPlayerObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MprisPlayerObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->TrackChange((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 1: _t->StatusChange((*reinterpret_cast< const MprisStatusStruct(*)>(_a[1]))); break;
        case 2: _t->CapsChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->Next(); break;
        case 4: _t->Prev(); break;
        case 5: _t->Pause(); break;
        case 6: _t->Stop(); break;
        case 7: _t->Play(); break;
        case 8: _t->Repeat((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: { MprisStatusStruct _r = _t->GetStatus();
            if (_a[0]) *reinterpret_cast< MprisStatusStruct*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariantMap _r = _t->GetMetadata();
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 11: { int _r = _t->GetCaps();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->VolumeSet((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: { int _r = _t->VolumeGet();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->PositionSet((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: { int _r = _t->PositionGet();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->IncreaseVolume(); break;
        case 17: _t->DecreaseVolume(); break;
        case 18: _t->ToggleMuted(); break;
        case 19: _t->ToggleFullScreen(); break;
        case 20: _t->ShortSkipBackward(); break;
        case 21: _t->ShortSkipForward(); break;
        case 22: _t->LongSkipBackward(); break;
        case 23: _t->LongSkipForward(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< MprisStatusStruct >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MprisPlayerObject::*)(const QVariantMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MprisPlayerObject::TrackChange)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MprisPlayerObject::*)(const MprisStatusStruct & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MprisPlayerObject::StatusChange)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (MprisPlayerObject::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MprisPlayerObject::CapsChange)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MprisPlayerObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_MprisPlayerObject.data,
    qt_meta_data_MprisPlayerObject,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MprisPlayerObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisPlayerObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MprisPlayerObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MprisPlayerObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void MprisPlayerObject::TrackChange(const QVariantMap & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MprisPlayerObject::StatusChange(const MprisStatusStruct & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void MprisPlayerObject::CapsChange(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
struct qt_meta_stringdata_MprisTrackListObject_t {
    QByteArrayData data[18];
    char stringdata0[199];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MprisTrackListObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MprisTrackListObject_t qt_meta_stringdata_MprisTrackListObject = {
    {
QT_MOC_LITERAL(0, 0, 20), // "MprisTrackListObject"
QT_MOC_LITERAL(1, 21, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 37, 27), // "org.freedesktop.MediaPlayer"
QT_MOC_LITERAL(3, 65, 15), // "TrackListChange"
QT_MOC_LITERAL(4, 81, 0), // ""
QT_MOC_LITERAL(5, 82, 4), // "size"
QT_MOC_LITERAL(6, 87, 11), // "GetMetadata"
QT_MOC_LITERAL(7, 99, 5), // "index"
QT_MOC_LITERAL(8, 105, 15), // "GetCurrentTrack"
QT_MOC_LITERAL(9, 121, 9), // "GetLength"
QT_MOC_LITERAL(10, 131, 8), // "AddTrack"
QT_MOC_LITERAL(11, 140, 3), // "url"
QT_MOC_LITERAL(12, 144, 15), // "playImmediately"
QT_MOC_LITERAL(13, 160, 8), // "DelTrack"
QT_MOC_LITERAL(14, 169, 7), // "SetLoop"
QT_MOC_LITERAL(15, 177, 4), // "loop"
QT_MOC_LITERAL(16, 182, 9), // "SetRandom"
QT_MOC_LITERAL(17, 192, 6) // "random"

    },
    "MprisTrackListObject\0D-Bus Interface\0"
    "org.freedesktop.MediaPlayer\0TrackListChange\0"
    "\0size\0GetMetadata\0index\0GetCurrentTrack\0"
    "GetLength\0AddTrack\0url\0playImmediately\0"
    "DelTrack\0SetLoop\0loop\0SetRandom\0random"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MprisTrackListObject[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       8,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // classinfo: key, value
       1,    2,

 // signals: name, argc, parameters, tag, flags
       3,    1,   56,    4, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   59,    4, 0x0a /* Public */,
       8,    0,   62,    4, 0x0a /* Public */,
       9,    0,   63,    4, 0x0a /* Public */,
      10,    2,   64,    4, 0x0a /* Public */,
      13,    1,   69,    4, 0x0a /* Public */,
      14,    1,   72,    4, 0x0a /* Public */,
      16,    1,   75,    4, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    5,

 // slots: parameters
    QMetaType::QVariantMap, QMetaType::Int,    7,
    QMetaType::Int,
    QMetaType::Int,
    QMetaType::Int, QMetaType::QString, QMetaType::Bool,   11,   12,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Bool,   15,
    QMetaType::Void, QMetaType::Bool,   17,

       0        // eod
};

void MprisTrackListObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MprisTrackListObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->TrackListChange((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: { QVariantMap _r = _t->GetMetadata((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 2: { int _r = _t->GetCurrentTrack();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 3: { int _r = _t->GetLength();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 4: { int _r = _t->AddTrack((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->DelTrack((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->SetLoop((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->SetRandom((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MprisTrackListObject::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MprisTrackListObject::TrackListChange)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MprisTrackListObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_MprisTrackListObject.data,
    qt_meta_data_MprisTrackListObject,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MprisTrackListObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisTrackListObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MprisTrackListObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MprisTrackListObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void MprisTrackListObject::TrackListChange(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_DBusTelevisionObject_t {
    QByteArrayData data[21];
    char stringdata0[282];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DBusTelevisionObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DBusTelevisionObject_t qt_meta_stringdata_DBusTelevisionObject = {
    {
QT_MOC_LITERAL(0, 0, 20), // "DBusTelevisionObject"
QT_MOC_LITERAL(1, 21, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 37, 27), // "org.freedesktop.MediaPlayer"
QT_MOC_LITERAL(3, 65, 12), // "DigitPressed"
QT_MOC_LITERAL(4, 78, 0), // ""
QT_MOC_LITERAL(5, 79, 5), // "digit"
QT_MOC_LITERAL(6, 85, 11), // "PlayChannel"
QT_MOC_LITERAL(7, 97, 12), // "nameOrNumber"
QT_MOC_LITERAL(8, 110, 15), // "PlayLastChannel"
QT_MOC_LITERAL(9, 126, 19), // "ToggleInstantRecord"
QT_MOC_LITERAL(10, 146, 9), // "ToggleOsd"
QT_MOC_LITERAL(11, 156, 19), // "ListProgramSchedule"
QT_MOC_LITERAL(12, 176, 36), // "QList<TelevisionScheduleEntry..."
QT_MOC_LITERAL(13, 213, 15), // "ScheduleProgram"
QT_MOC_LITERAL(14, 229, 4), // "name"
QT_MOC_LITERAL(15, 234, 7), // "channel"
QT_MOC_LITERAL(16, 242, 5), // "begin"
QT_MOC_LITERAL(17, 248, 8), // "duration"
QT_MOC_LITERAL(18, 257, 6), // "repeat"
QT_MOC_LITERAL(19, 264, 13), // "RemoveProgram"
QT_MOC_LITERAL(20, 278, 3) // "key"

    },
    "DBusTelevisionObject\0D-Bus Interface\0"
    "org.freedesktop.MediaPlayer\0DigitPressed\0"
    "\0digit\0PlayChannel\0nameOrNumber\0"
    "PlayLastChannel\0ToggleInstantRecord\0"
    "ToggleOsd\0ListProgramSchedule\0"
    "QList<TelevisionScheduleEntryStruct>\0"
    "ScheduleProgram\0name\0channel\0begin\0"
    "duration\0repeat\0RemoveProgram\0key"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DBusTelevisionObject[] = {

 // content:
       8,       // revision
       0,       // classname
       1,   14, // classinfo
       8,   16, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,

 // slots: name, argc, parameters, tag, flags
       3,    1,   56,    4, 0x0a /* Public */,
       6,    1,   59,    4, 0x0a /* Public */,
       8,    0,   62,    4, 0x0a /* Public */,
       9,    0,   63,    4, 0x0a /* Public */,
      10,    0,   64,    4, 0x0a /* Public */,
      11,    0,   65,    4, 0x0a /* Public */,
      13,    5,   66,    4, 0x0a /* Public */,
      19,    1,   77,    4, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    0x80000000 | 12,
    QMetaType::UInt, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int,   14,   15,   16,   17,   18,
    QMetaType::Void, QMetaType::UInt,   20,

       0        // eod
};

void DBusTelevisionObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DBusTelevisionObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->DigitPressed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->PlayChannel((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->PlayLastChannel(); break;
        case 3: _t->ToggleInstantRecord(); break;
        case 4: _t->ToggleOsd(); break;
        case 5: { QList<TelevisionScheduleEntryStruct> _r = _t->ListProgramSchedule();
            if (_a[0]) *reinterpret_cast< QList<TelevisionScheduleEntryStruct>*>(_a[0]) = std::move(_r); }  break;
        case 6: { quint32 _r = _t->ScheduleProgram((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5])));
            if (_a[0]) *reinterpret_cast< quint32*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->RemoveProgram((*reinterpret_cast< quint32(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DBusTelevisionObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DBusTelevisionObject.data,
    qt_meta_data_DBusTelevisionObject,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DBusTelevisionObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusTelevisionObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DBusTelevisionObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DBusTelevisionObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
