/****************************************************************************
** Meta object code from reading C++ file 'dvbrecordingdialog_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/dvb/dvbrecordingdialog_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dvbrecordingdialog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DvbRecordingTableModel_t {
    QByteArrayData data[8];
    char stringdata0[128];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbRecordingTableModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbRecordingTableModel_t qt_meta_stringdata_DvbRecordingTableModel = {
    {
QT_MOC_LITERAL(0, 0, 22), // "DvbRecordingTableModel"
QT_MOC_LITERAL(1, 23, 14), // "recordingAdded"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 18), // "DvbSharedRecording"
QT_MOC_LITERAL(4, 58, 9), // "recording"
QT_MOC_LITERAL(5, 68, 25), // "recordingAboutToBeUpdated"
QT_MOC_LITERAL(6, 94, 16), // "recordingUpdated"
QT_MOC_LITERAL(7, 111, 16) // "recordingRemoved"

    },
    "DvbRecordingTableModel\0recordingAdded\0"
    "\0DvbSharedRecording\0recording\0"
    "recordingAboutToBeUpdated\0recordingUpdated\0"
    "recordingRemoved"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbRecordingTableModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x08 /* Private */,
       5,    1,   37,    2, 0x08 /* Private */,
       6,    1,   40,    2, 0x08 /* Private */,
       7,    1,   43,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void DvbRecordingTableModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbRecordingTableModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->recordingAdded((*reinterpret_cast< const DvbSharedRecording(*)>(_a[1]))); break;
        case 1: _t->recordingAboutToBeUpdated((*reinterpret_cast< const DvbSharedRecording(*)>(_a[1]))); break;
        case 2: _t->recordingUpdated((*reinterpret_cast< const DvbSharedRecording(*)>(_a[1]))); break;
        case 3: _t->recordingRemoved((*reinterpret_cast< const DvbSharedRecording(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbRecordingTableModel::staticMetaObject = { {
    QMetaObject::SuperData::link<TableModel<DvbRecordingTableModelHelper>::staticMetaObject>(),
    qt_meta_stringdata_DvbRecordingTableModel.data,
    qt_meta_data_DvbRecordingTableModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbRecordingTableModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbRecordingTableModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbRecordingTableModel.stringdata0))
        return static_cast<void*>(this);
    return TableModel<DvbRecordingTableModelHelper>::qt_metacast(_clname);
}

int DvbRecordingTableModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TableModel<DvbRecordingTableModelHelper>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
struct qt_meta_stringdata_DvbRecordingEditor_t {
    QByteArrayData data[11];
    char stringdata0[117];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbRecordingEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbRecordingEditor_t qt_meta_stringdata_DvbRecordingEditor = {
    {
QT_MOC_LITERAL(0, 0, 18), // "DvbRecordingEditor"
QT_MOC_LITERAL(1, 19, 12), // "beginChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 5), // "begin"
QT_MOC_LITERAL(4, 39, 15), // "durationChanged"
QT_MOC_LITERAL(5, 55, 8), // "duration"
QT_MOC_LITERAL(6, 64, 10), // "endChanged"
QT_MOC_LITERAL(7, 75, 3), // "end"
QT_MOC_LITERAL(8, 79, 11), // "repeatNever"
QT_MOC_LITERAL(9, 91, 11), // "repeatDaily"
QT_MOC_LITERAL(10, 103, 13) // "checkValidity"

    },
    "DvbRecordingEditor\0beginChanged\0\0begin\0"
    "durationChanged\0duration\0endChanged\0"
    "end\0repeatNever\0repeatDaily\0checkValidity"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbRecordingEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x08 /* Private */,
       4,    1,   47,    2, 0x08 /* Private */,
       6,    1,   50,    2, 0x08 /* Private */,
       8,    0,   53,    2, 0x08 /* Private */,
       9,    0,   54,    2, 0x08 /* Private */,
      10,    0,   55,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QDateTime,    3,
    QMetaType::Void, QMetaType::QTime,    5,
    QMetaType::Void, QMetaType::QDateTime,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DvbRecordingEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbRecordingEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->beginChanged((*reinterpret_cast< const QDateTime(*)>(_a[1]))); break;
        case 1: _t->durationChanged((*reinterpret_cast< const QTime(*)>(_a[1]))); break;
        case 2: _t->endChanged((*reinterpret_cast< const QDateTime(*)>(_a[1]))); break;
        case 3: _t->repeatNever(); break;
        case 4: _t->repeatDaily(); break;
        case 5: _t->checkValidity(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbRecordingEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_DvbRecordingEditor.data,
    qt_meta_data_DvbRecordingEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbRecordingEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbRecordingEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbRecordingEditor.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int DvbRecordingEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
