/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/mainwindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[29];
    char stringdata0[338];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 19), // "mayCloseApplication"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 5), // "bool*"
QT_MOC_LITERAL(4, 38, 2), // "ok"
QT_MOC_LITERAL(5, 41, 8), // "QWidget*"
QT_MOC_LITERAL(6, 50, 6), // "parent"
QT_MOC_LITERAL(7, 57, 18), // "displayModeChanged"
QT_MOC_LITERAL(8, 76, 4), // "open"
QT_MOC_LITERAL(9, 81, 5), // "close"
QT_MOC_LITERAL(10, 87, 7), // "openUrl"
QT_MOC_LITERAL(11, 95, 3), // "url"
QT_MOC_LITERAL(12, 99, 11), // "openAudioCd"
QT_MOC_LITERAL(13, 111, 6), // "device"
QT_MOC_LITERAL(14, 118, 11), // "openVideoCd"
QT_MOC_LITERAL(15, 130, 7), // "openDvd"
QT_MOC_LITERAL(16, 138, 13), // "playDvdFolder"
QT_MOC_LITERAL(17, 152, 7), // "playDvb"
QT_MOC_LITERAL(18, 160, 13), // "configureKeys"
QT_MOC_LITERAL(19, 174, 17), // "configureKaffeine"
QT_MOC_LITERAL(20, 192, 31), // "navigationBarOrientationChanged"
QT_MOC_LITERAL(21, 224, 15), // "Qt::Orientation"
QT_MOC_LITERAL(22, 240, 11), // "orientation"
QT_MOC_LITERAL(23, 252, 11), // "activateTab"
QT_MOC_LITERAL(24, 264, 8), // "tabIndex"
QT_MOC_LITERAL(25, 273, 10), // "hideCursor"
QT_MOC_LITERAL(26, 284, 12), // "trayShowHide"
QT_MOC_LITERAL(27, 297, 33), // "QSystemTrayIcon::ActivationRe..."
QT_MOC_LITERAL(28, 331, 6) // "reason"

    },
    "MainWindow\0mayCloseApplication\0\0bool*\0"
    "ok\0QWidget*\0parent\0displayModeChanged\0"
    "open\0close\0openUrl\0url\0openAudioCd\0"
    "device\0openVideoCd\0openDvd\0playDvdFolder\0"
    "playDvb\0configureKeys\0configureKaffeine\0"
    "navigationBarOrientationChanged\0"
    "Qt::Orientation\0orientation\0activateTab\0"
    "tabIndex\0hideCursor\0trayShowHide\0"
    "QSystemTrayIcon::ActivationReason\0"
    "reason"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      20,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,  114,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,  119,    2, 0x08 /* Private */,
       8,    0,  120,    2, 0x08 /* Private */,
       9,    0,  121,    2, 0x08 /* Private */,
      10,    0,  122,    2, 0x08 /* Private */,
      10,    1,  123,    2, 0x08 /* Private */,
      12,    1,  126,    2, 0x08 /* Private */,
      12,    0,  129,    2, 0x28 /* Private | MethodCloned */,
      14,    1,  130,    2, 0x08 /* Private */,
      14,    0,  133,    2, 0x28 /* Private | MethodCloned */,
      15,    1,  134,    2, 0x08 /* Private */,
      15,    0,  137,    2, 0x28 /* Private | MethodCloned */,
      16,    0,  138,    2, 0x08 /* Private */,
      17,    0,  139,    2, 0x08 /* Private */,
      18,    0,  140,    2, 0x08 /* Private */,
      19,    0,  141,    2, 0x08 /* Private */,
      20,    1,  142,    2, 0x08 /* Private */,
      23,    1,  145,    2, 0x08 /* Private */,
      25,    0,  148,    2, 0x08 /* Private */,
      26,    1,  149,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,   11,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 21,   22,
    QMetaType::Void, QMetaType::Int,   24,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 27,   28,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->mayCloseApplication((*reinterpret_cast< bool*(*)>(_a[1])),(*reinterpret_cast< QWidget*(*)>(_a[2]))); break;
        case 1: _t->displayModeChanged(); break;
        case 2: _t->open(); break;
        case 3: _t->close(); break;
        case 4: _t->openUrl(); break;
        case 5: _t->openUrl((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 6: _t->openAudioCd((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->openAudioCd(); break;
        case 8: _t->openVideoCd((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->openVideoCd(); break;
        case 10: _t->openDvd((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 11: _t->openDvd(); break;
        case 12: _t->playDvdFolder(); break;
        case 13: _t->playDvb(); break;
        case 14: _t->configureKeys(); break;
        case 15: _t->configureKaffeine(); break;
        case 16: _t->navigationBarOrientationChanged((*reinterpret_cast< Qt::Orientation(*)>(_a[1]))); break;
        case 17: _t->activateTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->hideCursor(); break;
        case 19: _t->trayShowHide((*reinterpret_cast< QSystemTrayIcon::ActivationReason(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MainWindow::*)(bool * , QWidget * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::mayCloseApplication)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_MainWindow.data,
    qt_meta_data_MainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::mayCloseApplication(bool * _t1, QWidget * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
