/****************************************************************************
** Meta object code from reading C++ file 'dvbliveview.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/dvb/dvbliveview.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dvbliveview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DvbLiveView_t {
    QByteArrayData data[20];
    char stringdata0[294];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbLiveView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbLiveView_t qt_meta_stringdata_DvbLiveView = {
    {
QT_MOC_LITERAL(0, 0, 11), // "DvbLiveView"
QT_MOC_LITERAL(1, 12, 8), // "previous"
QT_MOC_LITERAL(2, 21, 0), // ""
QT_MOC_LITERAL(3, 22, 4), // "next"
QT_MOC_LITERAL(4, 27, 9), // "toggleOsd"
QT_MOC_LITERAL(5, 37, 17), // "pmtSectionChanged"
QT_MOC_LITERAL(6, 55, 14), // "pmtSectionData"
QT_MOC_LITERAL(7, 70, 12), // "insertPatPmt"
QT_MOC_LITERAL(8, 83, 18), // "deviceStateChanged"
QT_MOC_LITERAL(9, 102, 7), // "showOsd"
QT_MOC_LITERAL(10, 110, 10), // "osdTimeout"
QT_MOC_LITERAL(11, 121, 25), // "currentAudioStreamChanged"
QT_MOC_LITERAL(12, 147, 18), // "currentAudioStream"
QT_MOC_LITERAL(13, 166, 22), // "currentSubtitleChanged"
QT_MOC_LITERAL(14, 189, 15), // "currentSubtitle"
QT_MOC_LITERAL(15, 205, 6), // "replay"
QT_MOC_LITERAL(16, 212, 16), // "playbackFinished"
QT_MOC_LITERAL(17, 229, 21), // "playbackStatusChanged"
QT_MOC_LITERAL(18, 251, 27), // "MediaWidget::PlaybackStatus"
QT_MOC_LITERAL(19, 279, 14) // "playbackStatus"

    },
    "DvbLiveView\0previous\0\0next\0toggleOsd\0"
    "pmtSectionChanged\0pmtSectionData\0"
    "insertPatPmt\0deviceStateChanged\0showOsd\0"
    "osdTimeout\0currentAudioStreamChanged\0"
    "currentAudioStream\0currentSubtitleChanged\0"
    "currentSubtitle\0replay\0playbackFinished\0"
    "playbackStatusChanged\0MediaWidget::PlaybackStatus\0"
    "playbackStatus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbLiveView[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   79,    2, 0x06 /* Public */,
       3,    0,   80,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   81,    2, 0x0a /* Public */,
       5,    1,   82,    2, 0x08 /* Private */,
       7,    0,   85,    2, 0x08 /* Private */,
       8,    0,   86,    2, 0x08 /* Private */,
       9,    0,   87,    2, 0x08 /* Private */,
      10,    0,   88,    2, 0x08 /* Private */,
      11,    1,   89,    2, 0x08 /* Private */,
      13,    1,   92,    2, 0x08 /* Private */,
      15,    0,   95,    2, 0x08 /* Private */,
      16,    0,   96,    2, 0x08 /* Private */,
      17,    1,   97,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QByteArray,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void, QMetaType::Int,   14,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 18,   19,

       0        // eod
};

void DvbLiveView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbLiveView *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->previous(); break;
        case 1: _t->next(); break;
        case 2: _t->toggleOsd(); break;
        case 3: _t->pmtSectionChanged((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 4: _t->insertPatPmt(); break;
        case 5: _t->deviceStateChanged(); break;
        case 6: _t->showOsd(); break;
        case 7: _t->osdTimeout(); break;
        case 8: _t->currentAudioStreamChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->currentSubtitleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->replay(); break;
        case 11: _t->playbackFinished(); break;
        case 12: _t->playbackStatusChanged((*reinterpret_cast< MediaWidget::PlaybackStatus(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DvbLiveView::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveView::previous)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DvbLiveView::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbLiveView::next)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbLiveView::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DvbLiveView.data,
    qt_meta_data_DvbLiveView,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbLiveView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbLiveView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbLiveView.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DvbLiveView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void DvbLiveView::previous()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DvbLiveView::next()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
