/****************************************************************************
** Meta object code from reading C++ file 'dvbconfigdialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/dvb/dvbconfigdialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dvbconfigdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RegexInputLine_t {
    QByteArrayData data[1];
    char stringdata0[15];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RegexInputLine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RegexInputLine_t qt_meta_stringdata_RegexInputLine = {
    {
QT_MOC_LITERAL(0, 0, 14) // "RegexInputLine"

    },
    "RegexInputLine"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RegexInputLine[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void RegexInputLine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject RegexInputLine::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_RegexInputLine.data,
    qt_meta_data_RegexInputLine,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RegexInputLine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RegexInputLine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RegexInputLine.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RegexInputLine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_DvbConfigDialog_t {
    QByteArrayData data[17];
    char stringdata0[212];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbConfigDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbConfigDialog_t qt_meta_stringdata_DvbConfigDialog = {
    {
QT_MOC_LITERAL(0, 0, 15), // "DvbConfigDialog"
QT_MOC_LITERAL(1, 16, 11), // "removeRegex"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 14), // "DvbConfigPage*"
QT_MOC_LITERAL(4, 44, 4), // "page"
QT_MOC_LITERAL(5, 49, 21), // "changeRecordingFolder"
QT_MOC_LITERAL(6, 71, 21), // "changeTimeShiftFolder"
QT_MOC_LITERAL(7, 93, 19), // "changeXmltvFileName"
QT_MOC_LITERAL(8, 113, 14), // "updateScanFile"
QT_MOC_LITERAL(9, 128, 12), // "openScanFile"
QT_MOC_LITERAL(10, 141, 8), // "newRegex"
QT_MOC_LITERAL(11, 150, 19), // "namingFormatChanged"
QT_MOC_LITERAL(12, 170, 4), // "text"
QT_MOC_LITERAL(13, 175, 8), // "moveLeft"
QT_MOC_LITERAL(14, 184, 10), // "configPage"
QT_MOC_LITERAL(15, 195, 9), // "moveRight"
QT_MOC_LITERAL(16, 205, 6) // "remove"

    },
    "DvbConfigDialog\0removeRegex\0\0"
    "DvbConfigPage*\0page\0changeRecordingFolder\0"
    "changeTimeShiftFolder\0changeXmltvFileName\0"
    "updateScanFile\0openScanFile\0newRegex\0"
    "namingFormatChanged\0text\0moveLeft\0"
    "configPage\0moveRight\0remove"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbConfigDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   77,    2, 0x08 /* Private */,
       6,    0,   78,    2, 0x08 /* Private */,
       7,    0,   79,    2, 0x08 /* Private */,
       8,    0,   80,    2, 0x08 /* Private */,
       9,    0,   81,    2, 0x08 /* Private */,
      10,    0,   82,    2, 0x08 /* Private */,
       1,    0,   83,    2, 0x08 /* Private */,
      11,    1,   84,    2, 0x08 /* Private */,
      13,    1,   87,    2, 0x08 /* Private */,
      15,    1,   90,    2, 0x08 /* Private */,
      16,    1,   93,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   12,
    QMetaType::Void, 0x80000000 | 3,   14,
    QMetaType::Void, 0x80000000 | 3,   14,
    QMetaType::Void, 0x80000000 | 3,   14,

       0        // eod
};

void DvbConfigDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbConfigDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->removeRegex((*reinterpret_cast< DvbConfigPage*(*)>(_a[1]))); break;
        case 1: _t->changeRecordingFolder(); break;
        case 2: _t->changeTimeShiftFolder(); break;
        case 3: _t->changeXmltvFileName(); break;
        case 4: _t->updateScanFile(); break;
        case 5: _t->openScanFile(); break;
        case 6: _t->newRegex(); break;
        case 7: _t->removeRegex(); break;
        case 8: _t->namingFormatChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 9: _t->moveLeft((*reinterpret_cast< DvbConfigPage*(*)>(_a[1]))); break;
        case 10: _t->moveRight((*reinterpret_cast< DvbConfigPage*(*)>(_a[1]))); break;
        case 11: _t->remove((*reinterpret_cast< DvbConfigPage*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DvbConfigPage* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DvbConfigPage* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DvbConfigPage* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DvbConfigPage* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DvbConfigDialog::*)(DvbConfigPage * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbConfigDialog::removeRegex)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbConfigDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_DvbConfigDialog.data,
    qt_meta_data_DvbConfigDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbConfigDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbConfigDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbConfigDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int DvbConfigDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void DvbConfigDialog::removeRegex(DvbConfigPage * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_DvbScanFileDownloadDialog_t {
    QByteArrayData data[9];
    char stringdata0[96];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbScanFileDownloadDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbScanFileDownloadDialog_t qt_meta_stringdata_DvbScanFileDownloadDialog = {
    {
QT_MOC_LITERAL(0, 0, 25), // "DvbScanFileDownloadDialog"
QT_MOC_LITERAL(1, 26, 15), // "progressChanged"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 5), // "KJob*"
QT_MOC_LITERAL(4, 49, 7), // "percent"
QT_MOC_LITERAL(5, 57, 11), // "dataArrived"
QT_MOC_LITERAL(6, 69, 9), // "KIO::Job*"
QT_MOC_LITERAL(7, 79, 4), // "data"
QT_MOC_LITERAL(8, 84, 11) // "jobFinished"

    },
    "DvbScanFileDownloadDialog\0progressChanged\0"
    "\0KJob*\0percent\0dataArrived\0KIO::Job*\0"
    "data\0jobFinished"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbScanFileDownloadDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x08 /* Private */,
       5,    2,   34,    2, 0x08 /* Private */,
       8,    0,   39,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::ULong,    2,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QByteArray,    2,    7,
    QMetaType::Void,

       0        // eod
};

void DvbScanFileDownloadDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbScanFileDownloadDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->progressChanged((*reinterpret_cast< KJob*(*)>(_a[1])),(*reinterpret_cast< ulong(*)>(_a[2]))); break;
        case 1: _t->dataArrived((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 2: _t->jobFinished(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbScanFileDownloadDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_DvbScanFileDownloadDialog.data,
    qt_meta_data_DvbScanFileDownloadDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbScanFileDownloadDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbScanFileDownloadDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbScanFileDownloadDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int DvbScanFileDownloadDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
struct qt_meta_stringdata_DvbConfigPage_t {
    QByteArrayData data[9];
    char stringdata0[86];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbConfigPage_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbConfigPage_t qt_meta_stringdata_DvbConfigPage = {
    {
QT_MOC_LITERAL(0, 0, 13), // "DvbConfigPage"
QT_MOC_LITERAL(1, 14, 8), // "moveLeft"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 14), // "DvbConfigPage*"
QT_MOC_LITERAL(4, 39, 4), // "page"
QT_MOC_LITERAL(5, 44, 9), // "moveRight"
QT_MOC_LITERAL(6, 54, 6), // "remove"
QT_MOC_LITERAL(7, 61, 11), // "resetConfig"
QT_MOC_LITERAL(8, 73, 12) // "removeConfig"

    },
    "DvbConfigPage\0moveLeft\0\0DvbConfigPage*\0"
    "page\0moveRight\0remove\0resetConfig\0"
    "removeConfig"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbConfigPage[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   49,    2, 0x06 /* Public */,
       5,    1,   52,    2, 0x06 /* Public */,
       6,    1,   55,    2, 0x06 /* Public */,
       7,    0,   58,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x08 /* Private */,
       5,    0,   60,    2, 0x08 /* Private */,
       8,    0,   61,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DvbConfigPage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbConfigPage *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->moveLeft((*reinterpret_cast< DvbConfigPage*(*)>(_a[1]))); break;
        case 1: _t->moveRight((*reinterpret_cast< DvbConfigPage*(*)>(_a[1]))); break;
        case 2: _t->remove((*reinterpret_cast< DvbConfigPage*(*)>(_a[1]))); break;
        case 3: _t->resetConfig(); break;
        case 4: _t->moveLeft(); break;
        case 5: _t->moveRight(); break;
        case 6: _t->removeConfig(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DvbConfigPage* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DvbConfigPage* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DvbConfigPage* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DvbConfigPage::*)(DvbConfigPage * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbConfigPage::moveLeft)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DvbConfigPage::*)(DvbConfigPage * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbConfigPage::moveRight)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DvbConfigPage::*)(DvbConfigPage * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbConfigPage::remove)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DvbConfigPage::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbConfigPage::resetConfig)) {
                *result = 3;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbConfigPage::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_DvbConfigPage.data,
    qt_meta_data_DvbConfigPage,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbConfigPage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbConfigPage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbConfigPage.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int DvbConfigPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void DvbConfigPage::moveLeft(DvbConfigPage * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DvbConfigPage::moveRight(DvbConfigPage * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DvbConfigPage::remove(DvbConfigPage * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DvbConfigPage::resetConfig()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
struct qt_meta_stringdata_DvbConfigObject_t {
    QByteArrayData data[8];
    char stringdata0[84];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbConfigObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbConfigObject_t qt_meta_stringdata_DvbConfigObject = {
    {
QT_MOC_LITERAL(0, 0, 15), // "DvbConfigObject"
QT_MOC_LITERAL(1, 16, 14), // "timeoutChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 7), // "timeout"
QT_MOC_LITERAL(4, 40, 13), // "sourceChanged"
QT_MOC_LITERAL(5, 54, 5), // "index"
QT_MOC_LITERAL(6, 60, 11), // "nameChanged"
QT_MOC_LITERAL(7, 72, 11) // "resetConfig"

    },
    "DvbConfigObject\0timeoutChanged\0\0timeout\0"
    "sourceChanged\0index\0nameChanged\0"
    "resetConfig"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbConfigObject[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x08 /* Private */,
       4,    1,   37,    2, 0x08 /* Private */,
       6,    0,   40,    2, 0x08 /* Private */,
       7,    0,   41,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    5,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DvbConfigObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbConfigObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->timeoutChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->sourceChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->nameChanged(); break;
        case 3: _t->resetConfig(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbConfigObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DvbConfigObject.data,
    qt_meta_data_DvbConfigObject,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbConfigObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbConfigObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbConfigObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DvbConfigObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
struct qt_meta_stringdata_DvbSConfigObject_t {
    QByteArrayData data[16];
    char stringdata0[213];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbSConfigObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbSConfigObject_t qt_meta_stringdata_DvbSConfigObject = {
    {
QT_MOC_LITERAL(0, 0, 16), // "DvbSConfigObject"
QT_MOC_LITERAL(1, 17, 16), // "setDiseqcVisible"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 7), // "visible"
QT_MOC_LITERAL(4, 43, 18), // "setFirstLnbVisible"
QT_MOC_LITERAL(5, 62, 15), // "setRotorVisible"
QT_MOC_LITERAL(6, 78, 15), // "setUsalsVisible"
QT_MOC_LITERAL(7, 94, 19), // "setPositionsVisible"
QT_MOC_LITERAL(8, 114, 15), // "latitudeChanged"
QT_MOC_LITERAL(9, 130, 4), // "text"
QT_MOC_LITERAL(10, 135, 16), // "longitudeChanged"
QT_MOC_LITERAL(11, 152, 13), // "configChanged"
QT_MOC_LITERAL(12, 166, 5), // "index"
QT_MOC_LITERAL(13, 172, 12), // "addSatellite"
QT_MOC_LITERAL(14, 185, 15), // "removeSatellite"
QT_MOC_LITERAL(15, 201, 11) // "resetConfig"

    },
    "DvbSConfigObject\0setDiseqcVisible\0\0"
    "visible\0setFirstLnbVisible\0setRotorVisible\0"
    "setUsalsVisible\0setPositionsVisible\0"
    "latitudeChanged\0text\0longitudeChanged\0"
    "configChanged\0index\0addSatellite\0"
    "removeSatellite\0resetConfig"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbSConfigObject[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   69,    2, 0x06 /* Public */,
       4,    1,   72,    2, 0x06 /* Public */,
       5,    1,   75,    2, 0x06 /* Public */,
       6,    1,   78,    2, 0x06 /* Public */,
       7,    1,   81,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   84,    2, 0x08 /* Private */,
      10,    1,   87,    2, 0x08 /* Private */,
      11,    1,   90,    2, 0x08 /* Private */,
      13,    0,   93,    2, 0x08 /* Private */,
      14,    0,   94,    2, 0x08 /* Private */,
      15,    0,   95,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    3,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DvbSConfigObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbSConfigObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setDiseqcVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->setFirstLnbVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setRotorVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setUsalsVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->setPositionsVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->latitudeChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 6: _t->longitudeChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->configChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->addSatellite(); break;
        case 9: _t->removeSatellite(); break;
        case 10: _t->resetConfig(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DvbSConfigObject::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbSConfigObject::setDiseqcVisible)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DvbSConfigObject::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbSConfigObject::setFirstLnbVisible)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DvbSConfigObject::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbSConfigObject::setRotorVisible)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DvbSConfigObject::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbSConfigObject::setUsalsVisible)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DvbSConfigObject::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DvbSConfigObject::setPositionsVisible)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbSConfigObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DvbSConfigObject.data,
    qt_meta_data_DvbSConfigObject,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbSConfigObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbSConfigObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbSConfigObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DvbSConfigObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void DvbSConfigObject::setDiseqcVisible(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DvbSConfigObject::setFirstLnbVisible(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DvbSConfigObject::setRotorVisible(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DvbSConfigObject::setUsalsVisible(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void DvbSConfigObject::setPositionsVisible(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
struct qt_meta_stringdata_DvbSLnbConfigObject_t {
    QByteArrayData data[11];
    char stringdata0[124];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DvbSLnbConfigObject_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DvbSLnbConfigObject_t qt_meta_stringdata_DvbSLnbConfigObject = {
    {
QT_MOC_LITERAL(0, 0, 19), // "DvbSLnbConfigObject"
QT_MOC_LITERAL(1, 20, 14), // "timeoutChanged"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 5), // "value"
QT_MOC_LITERAL(4, 42, 20), // "higherVoltageChanged"
QT_MOC_LITERAL(5, 63, 13), // "sourceChanged"
QT_MOC_LITERAL(6, 77, 5), // "index"
QT_MOC_LITERAL(7, 83, 9), // "configure"
QT_MOC_LITERAL(8, 93, 10), // "selectType"
QT_MOC_LITERAL(9, 104, 4), // "type"
QT_MOC_LITERAL(10, 109, 14) // "dialogAccepted"

    },
    "DvbSLnbConfigObject\0timeoutChanged\0\0"
    "value\0higherVoltageChanged\0sourceChanged\0"
    "index\0configure\0selectType\0type\0"
    "dialogAccepted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DvbSLnbConfigObject[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x08 /* Private */,
       4,    1,   47,    2, 0x08 /* Private */,
       5,    1,   50,    2, 0x08 /* Private */,
       7,    0,   53,    2, 0x08 /* Private */,
       8,    1,   54,    2, 0x08 /* Private */,
      10,    0,   57,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void, QMetaType::Int,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    9,
    QMetaType::Void,

       0        // eod
};

void DvbSLnbConfigObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DvbSLnbConfigObject *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->timeoutChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->higherVoltageChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->sourceChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->configure(); break;
        case 4: _t->selectType((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->dialogAccepted(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject DvbSLnbConfigObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DvbSLnbConfigObject.data,
    qt_meta_data_DvbSLnbConfigObject,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DvbSLnbConfigObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DvbSLnbConfigObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DvbSLnbConfigObject.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DvbSLnbConfigObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
