/****************************************************************************
** Meta object code from reading C++ file 'mediawidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kaffeine/src/mediawidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mediawidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MediaWidget_t {
    QByteArrayData data[64];
    char stringdata0[948];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MediaWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MediaWidget_t qt_meta_stringdata_MediaWidget = {
    {
QT_MOC_LITERAL(0, 0, 11), // "MediaWidget"
QT_MOC_LITERAL(1, 12, 18), // "displayModeChanged"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 13), // "changeCaption"
QT_MOC_LITERAL(4, 46, 7), // "caption"
QT_MOC_LITERAL(5, 54, 13), // "resizeToVideo"
QT_MOC_LITERAL(6, 68, 12), // "resizeFactor"
QT_MOC_LITERAL(7, 81, 16), // "playlistPrevious"
QT_MOC_LITERAL(8, 98, 12), // "playlistNext"
QT_MOC_LITERAL(9, 111, 19), // "playlistUrlsDropped"
QT_MOC_LITERAL(10, 131, 11), // "QList<QUrl>"
QT_MOC_LITERAL(11, 143, 4), // "urls"
QT_MOC_LITERAL(12, 148, 26), // "playlistTrackLengthChanged"
QT_MOC_LITERAL(13, 175, 6), // "length"
QT_MOC_LITERAL(14, 182, 28), // "playlistTrackMetadataChanged"
QT_MOC_LITERAL(15, 211, 39), // "QMap<MediaWidget::MetadataTyp..."
QT_MOC_LITERAL(16, 251, 8), // "metadata"
QT_MOC_LITERAL(17, 260, 13), // "osdKeyPressed"
QT_MOC_LITERAL(18, 274, 3), // "key"
QT_MOC_LITERAL(19, 278, 8), // "previous"
QT_MOC_LITERAL(20, 287, 4), // "next"
QT_MOC_LITERAL(21, 292, 4), // "stop"
QT_MOC_LITERAL(22, 297, 14), // "increaseVolume"
QT_MOC_LITERAL(23, 312, 14), // "decreaseVolume"
QT_MOC_LITERAL(24, 327, 16), // "toggleFullScreen"
QT_MOC_LITERAL(25, 344, 17), // "toggleMinimalMode"
QT_MOC_LITERAL(26, 362, 17), // "shortSkipBackward"
QT_MOC_LITERAL(27, 380, 16), // "shortSkipForward"
QT_MOC_LITERAL(28, 397, 16), // "longSkipBackward"
QT_MOC_LITERAL(29, 414, 15), // "longSkipForward"
QT_MOC_LITERAL(30, 430, 15), // "getAudioDevices"
QT_MOC_LITERAL(31, 446, 12), // "openSubtitle"
QT_MOC_LITERAL(32, 459, 11), // "setSubtitle"
QT_MOC_LITERAL(33, 471, 4), // "text"
QT_MOC_LITERAL(34, 476, 16), // "checkScreenSaver"
QT_MOC_LITERAL(35, 493, 9), // "noDisable"
QT_MOC_LITERAL(36, 503, 12), // "setAudioCard"
QT_MOC_LITERAL(37, 516, 12), // "mutedChanged"
QT_MOC_LITERAL(38, 529, 13), // "volumeChanged"
QT_MOC_LITERAL(39, 543, 6), // "volume"
QT_MOC_LITERAL(40, 550, 4), // "seek"
QT_MOC_LITERAL(41, 555, 8), // "position"
QT_MOC_LITERAL(42, 564, 20), // "deinterlacingChanged"
QT_MOC_LITERAL(43, 585, 8), // "QAction*"
QT_MOC_LITERAL(44, 594, 6), // "action"
QT_MOC_LITERAL(45, 601, 18), // "aspectRatioChanged"
QT_MOC_LITERAL(46, 620, 12), // "setVideoSize"
QT_MOC_LITERAL(47, 633, 19), // "autoResizeTriggered"
QT_MOC_LITERAL(48, 653, 13), // "pausedChanged"
QT_MOC_LITERAL(49, 667, 6), // "paused"
QT_MOC_LITERAL(50, 674, 17), // "timeButtonClicked"
QT_MOC_LITERAL(51, 692, 14), // "jumpToPosition"
QT_MOC_LITERAL(52, 707, 25), // "currentAudioStreamChanged"
QT_MOC_LITERAL(53, 733, 18), // "currentAudioStream"
QT_MOC_LITERAL(54, 752, 22), // "currentSubtitleChanged"
QT_MOC_LITERAL(55, 775, 15), // "currentSubtitle"
QT_MOC_LITERAL(56, 791, 10), // "toggleMenu"
QT_MOC_LITERAL(57, 802, 19), // "currentTitleChanged"
QT_MOC_LITERAL(58, 822, 21), // "currentChapterChanged"
QT_MOC_LITERAL(59, 844, 19), // "currentAngleChanged"
QT_MOC_LITERAL(60, 864, 24), // "shortSkipDurationChanged"
QT_MOC_LITERAL(61, 889, 17), // "shortSkipDuration"
QT_MOC_LITERAL(62, 907, 23), // "longSkipDurationChanged"
QT_MOC_LITERAL(63, 931, 16) // "longSkipDuration"

    },
    "MediaWidget\0displayModeChanged\0\0"
    "changeCaption\0caption\0resizeToVideo\0"
    "resizeFactor\0playlistPrevious\0"
    "playlistNext\0playlistUrlsDropped\0"
    "QList<QUrl>\0urls\0playlistTrackLengthChanged\0"
    "length\0playlistTrackMetadataChanged\0"
    "QMap<MediaWidget::MetadataType,QString>\0"
    "metadata\0osdKeyPressed\0key\0previous\0"
    "next\0stop\0increaseVolume\0decreaseVolume\0"
    "toggleFullScreen\0toggleMinimalMode\0"
    "shortSkipBackward\0shortSkipForward\0"
    "longSkipBackward\0longSkipForward\0"
    "getAudioDevices\0openSubtitle\0setSubtitle\0"
    "text\0checkScreenSaver\0noDisable\0"
    "setAudioCard\0mutedChanged\0volumeChanged\0"
    "volume\0seek\0position\0deinterlacingChanged\0"
    "QAction*\0action\0aspectRatioChanged\0"
    "setVideoSize\0autoResizeTriggered\0"
    "pausedChanged\0paused\0timeButtonClicked\0"
    "jumpToPosition\0currentAudioStreamChanged\0"
    "currentAudioStream\0currentSubtitleChanged\0"
    "currentSubtitle\0toggleMenu\0"
    "currentTitleChanged\0currentChapterChanged\0"
    "currentAngleChanged\0shortSkipDurationChanged\0"
    "shortSkipDuration\0longSkipDurationChanged\0"
    "longSkipDuration"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MediaWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      44,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  234,    2, 0x06 /* Public */,
       3,    1,  235,    2, 0x06 /* Public */,
       5,    1,  238,    2, 0x06 /* Public */,
       7,    0,  241,    2, 0x06 /* Public */,
       8,    0,  242,    2, 0x06 /* Public */,
       9,    1,  243,    2, 0x06 /* Public */,
      12,    1,  246,    2, 0x06 /* Public */,
      14,    1,  249,    2, 0x06 /* Public */,
      17,    1,  252,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      19,    0,  255,    2, 0x0a /* Public */,
      20,    0,  256,    2, 0x0a /* Public */,
      21,    0,  257,    2, 0x0a /* Public */,
      22,    0,  258,    2, 0x0a /* Public */,
      23,    0,  259,    2, 0x0a /* Public */,
      24,    0,  260,    2, 0x0a /* Public */,
      25,    0,  261,    2, 0x0a /* Public */,
      26,    0,  262,    2, 0x0a /* Public */,
      27,    0,  263,    2, 0x0a /* Public */,
      28,    0,  264,    2, 0x0a /* Public */,
      29,    0,  265,    2, 0x0a /* Public */,
      30,    0,  266,    2, 0x0a /* Public */,
      31,    0,  267,    2, 0x0a /* Public */,
      32,    1,  268,    2, 0x0a /* Public */,
      34,    1,  271,    2, 0x08 /* Private */,
      34,    0,  274,    2, 0x28 /* Private | MethodCloned */,
      36,    0,  275,    2, 0x08 /* Private */,
      37,    0,  276,    2, 0x08 /* Private */,
      38,    1,  277,    2, 0x08 /* Private */,
      40,    1,  280,    2, 0x08 /* Private */,
      42,    1,  283,    2, 0x08 /* Private */,
      45,    1,  286,    2, 0x08 /* Private */,
      46,    0,  289,    2, 0x08 /* Private */,
      47,    1,  290,    2, 0x08 /* Private */,
      48,    1,  293,    2, 0x08 /* Private */,
      50,    0,  296,    2, 0x08 /* Private */,
      51,    0,  297,    2, 0x08 /* Private */,
      52,    1,  298,    2, 0x08 /* Private */,
      54,    1,  301,    2, 0x08 /* Private */,
      56,    0,  304,    2, 0x08 /* Private */,
      57,    1,  305,    2, 0x08 /* Private */,
      58,    1,  308,    2, 0x08 /* Private */,
      59,    1,  311,    2, 0x08 /* Private */,
      60,    1,  314,    2, 0x08 /* Private */,
      62,    1,  317,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    4,
    QMetaType::Void, QMetaType::Float,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 10,   11,
    QMetaType::Void, QMetaType::Int,   13,
    QMetaType::Void, 0x80000000 | 15,   16,
    QMetaType::Void, QMetaType::Int,   18,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,   33,
    QMetaType::Void, QMetaType::Bool,   35,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   39,
    QMetaType::Void, QMetaType::Int,   41,
    QMetaType::Void, 0x80000000 | 43,   44,
    QMetaType::Void, 0x80000000 | 43,   44,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 43,   44,
    QMetaType::Void, QMetaType::Bool,   49,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   53,
    QMetaType::Void, QMetaType::Int,   55,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 43,   44,
    QMetaType::Void, 0x80000000 | 43,   44,
    QMetaType::Void, 0x80000000 | 43,   44,
    QMetaType::Void, QMetaType::Int,   61,
    QMetaType::Void, QMetaType::Int,   63,

       0        // eod
};

void MediaWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MediaWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->displayModeChanged(); break;
        case 1: _t->changeCaption((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->resizeToVideo((*reinterpret_cast< float(*)>(_a[1]))); break;
        case 3: _t->playlistPrevious(); break;
        case 4: _t->playlistNext(); break;
        case 5: _t->playlistUrlsDropped((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 6: _t->playlistTrackLengthChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->playlistTrackMetadataChanged((*reinterpret_cast< const QMap<MediaWidget::MetadataType,QString>(*)>(_a[1]))); break;
        case 8: _t->osdKeyPressed((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->previous(); break;
        case 10: _t->next(); break;
        case 11: _t->stop(); break;
        case 12: _t->increaseVolume(); break;
        case 13: _t->decreaseVolume(); break;
        case 14: _t->toggleFullScreen(); break;
        case 15: _t->toggleMinimalMode(); break;
        case 16: _t->shortSkipBackward(); break;
        case 17: _t->shortSkipForward(); break;
        case 18: _t->longSkipBackward(); break;
        case 19: _t->longSkipForward(); break;
        case 20: _t->getAudioDevices(); break;
        case 21: _t->openSubtitle(); break;
        case 22: _t->setSubtitle((*reinterpret_cast< QUrl(*)>(_a[1]))); break;
        case 23: _t->checkScreenSaver((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 24: _t->checkScreenSaver(); break;
        case 25: _t->setAudioCard(); break;
        case 26: _t->mutedChanged(); break;
        case 27: _t->volumeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 28: _t->seek((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 29: _t->deinterlacingChanged((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 30: _t->aspectRatioChanged((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 31: _t->setVideoSize(); break;
        case 32: _t->autoResizeTriggered((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 33: _t->pausedChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 34: _t->timeButtonClicked(); break;
        case 35: _t->jumpToPosition(); break;
        case 36: _t->currentAudioStreamChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 37: _t->currentSubtitleChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 38: _t->toggleMenu(); break;
        case 39: _t->currentTitleChanged((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 40: _t->currentChapterChanged((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 41: _t->currentAngleChanged((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 42: _t->shortSkipDurationChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 43: _t->longSkipDurationChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 39:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MediaWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::displayModeChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MediaWidget::*)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::changeCaption)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (MediaWidget::*)(float );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::resizeToVideo)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (MediaWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::playlistPrevious)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (MediaWidget::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::playlistNext)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (MediaWidget::*)(const QList<QUrl> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::playlistUrlsDropped)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (MediaWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::playlistTrackLengthChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (MediaWidget::*)(const QMap<MediaWidget::MetadataType,QString> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::playlistTrackMetadataChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (MediaWidget::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MediaWidget::osdKeyPressed)) {
                *result = 8;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MediaWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_MediaWidget.data,
    qt_meta_data_MediaWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MediaWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MediaWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MediaWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MediaWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void MediaWidget::displayModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MediaWidget::changeCaption(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void MediaWidget::resizeToVideo(float _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void MediaWidget::playlistPrevious()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MediaWidget::playlistNext()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MediaWidget::playlistUrlsDropped(const QList<QUrl> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void MediaWidget::playlistTrackLengthChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void MediaWidget::playlistTrackMetadataChanged(const QMap<MediaWidget::MetadataType,QString> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void MediaWidget::osdKeyPressed(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
